==> aws_cdk.aws_auditmanager-1.155.0-py3-none-any.whl: package/.warnings.jsii.js <==
function _aws_cdk_aws_auditmanager_CfnAssessmentProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (!visitedObjects.has(p.assessmentReportsDestination))
            _aws_cdk_aws_auditmanager_CfnAssessment_AssessmentReportsDestinationProperty(p.assessmentReportsDestination);
        if (!visitedObjects.has(p.tags))
            require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function _aws_cdk_aws_auditmanager_CfnAssessment(p) {
}
function _aws_cdk_aws_auditmanager_CfnAssessment_AWSAccountProperty(p) {
}
function _aws_cdk_aws_auditmanager_CfnAssessment_AWSServiceProperty(p) {
}
function _aws_cdk_aws_auditmanager_CfnAssessment_AssessmentReportsDestinationProperty(p) {
}
function _aws_cdk_aws_auditmanager_CfnAssessment_DelegationProperty(p) {
}
function _aws_cdk_aws_auditmanager_CfnAssessment_RoleProperty(p) {
}
function _aws_cdk_aws_auditmanager_CfnAssessment_ScopeProperty(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage.trim()}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
function getPropertyDescriptor(obj, prop) {
    const descriptor = Object.getOwnPropertyDescriptor(obj, prop);
    if (descriptor) {
        return descriptor;
    }
    const proto = Object.getPrototypeOf(obj);
    const prototypeDescriptor = proto && getPropertyDescriptor(proto, prop);
    if (prototypeDescriptor) {
        return prototypeDescriptor;
    }
    return {};
}
const visitedObjects = new Set();
class DeprecationError extends Error {
    constructor(...args) {
        super(...args);
        Object.defineProperty(this, "name", {
            configurable: false,
            enumerable: true,
            value: "DeprecationError",
            writable: false,
        });
    }
}
module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_auditmanager_CfnAssessmentProps, _aws_cdk_aws_auditmanager_CfnAssessment, _aws_cdk_aws_auditmanager_CfnAssessment_AWSAccountProperty, _aws_cdk_aws_auditmanager_CfnAssessment_AWSServiceProperty, _aws_cdk_aws_auditmanager_CfnAssessment_AssessmentReportsDestinationProperty, _aws_cdk_aws_auditmanager_CfnAssessment_DelegationProperty, _aws_cdk_aws_auditmanager_CfnAssessment_RoleProperty, _aws_cdk_aws_auditmanager_CfnAssessment_ScopeProperty };

==> aws_cdk.aws_auditmanager-1.177.0-py3-none-any.whl: package/.warnings.jsii.js <==
function _aws_cdk_aws_auditmanager_CfnAssessmentProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (!visitedObjects.has(p.assessmentReportsDestination))
            _aws_cdk_aws_auditmanager_CfnAssessment_AssessmentReportsDestinationProperty(p.assessmentReportsDestination);
        if (p.tags != null)
            for (const o of p.tags)
                if (!visitedObjects.has(o))
                    require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(o);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function _aws_cdk_aws_auditmanager_CfnAssessment(p) {
}
function _aws_cdk_aws_auditmanager_CfnAssessment_AWSAccountProperty(p) {
}
function _aws_cdk_aws_auditmanager_CfnAssessment_AWSServiceProperty(p) {
}
function _aws_cdk_aws_auditmanager_CfnAssessment_AssessmentReportsDestinationProperty(p) {
}
function _aws_cdk_aws_auditmanager_CfnAssessment_DelegationProperty(p) {
}
function _aws_cdk_aws_auditmanager_CfnAssessment_RoleProperty(p) {
}
function _aws_cdk_aws_auditmanager_CfnAssessment_ScopeProperty(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage.trim()}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
function getPropertyDescriptor(obj, prop) {
    const descriptor = Object.getOwnPropertyDescriptor(obj, prop);
    if (descriptor) {
        return descriptor;
    }
    const proto = Object.getPrototypeOf(obj);
    const prototypeDescriptor = proto && getPropertyDescriptor(proto, prop);
    if (prototypeDescriptor) {
        return prototypeDescriptor;
    }
    return {};
}
const visitedObjects = new Set();
class DeprecationError extends Error {
    constructor(...args) {
        super(...args);
        Object.defineProperty(this, "name", {
            configurable: false,
            enumerable: true,
            value: "DeprecationError",
            writable: false,
        });
    }
}
module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_auditmanager_CfnAssessmentProps, _aws_cdk_aws_auditmanager_CfnAssessment, _aws_cdk_aws_auditmanager_CfnAssessment_AWSAccountProperty, _aws_cdk_aws_auditmanager_CfnAssessment_AWSServiceProperty, _aws_cdk_aws_auditmanager_CfnAssessment_AssessmentReportsDestinationProperty, _aws_cdk_aws_auditmanager_CfnAssessment_DelegationProperty, _aws_cdk_aws_auditmanager_CfnAssessment_RoleProperty, _aws_cdk_aws_auditmanager_CfnAssessment_ScopeProperty };
